
* smartly create patches from files in the patch repository (dealing with cases
  where two different patches in two branches use the same file, or when an
  already used patch name is reused later)

* patches are workflowable, so it's easy to find those which are in-progress or
  pending for review

* you can add comment and tasks to the patch or/and to each diff chunk

* notification about patches activity
